@@ -64,7 +64,7 @@ struct _WsDbrelsPrivate
 	GObject        *sel_obj;
 };
 
-guint
+GType
 ws_dbrels_get_type (void)
 {
 	static GType type = 0;
